@@ -16,10 +16,11 @@
 #   License along with this library; if not, write to the Free Software
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import gtk, gtk.glade, gmenu, gobject, gnomevfs, gnome.ui
+import gtk, gtk.glade, gmenu, gobject, gio
 import cgi, os
 import gettext
 import subprocess
+import urllib
 try:
 	from Alacarte import config
 	gettext.bindtextdomain('alacarte',config.localedir)
@@ -47,7 +48,6 @@ class MainWindow:
 		self.file_path = datadir
 		self.version = version
 		self.editor = MenuEditor()
-		self.gnome_program = gnome.init('alacarte', version)
 		gtk.window_set_default_icon_name('alacarte')
 		self.tree = gtk.glade.XML(os.path.join(self.file_path, 'alacarte.glade'))
 		signals = {}
@@ -70,7 +70,6 @@ class MainWindow:
 		keyval, modifier = gtk.accelerator_parse('F1')
 		accelgroup.connect_group(keyval, modifier, gtk.ACCEL_VISIBLE, self.on_help_button_clicked)
 		self.tree.get_widget('mainwindow').add_accel_group(accelgroup)
-		gnome.ui.authentication_manager_init()
 
 	def run(self):
 		self.loadMenus()
@@ -535,21 +534,18 @@ class MainWindow:
 			else:
 				path = (len(items) - 1,)
 				after = items[path][3]
-			file_path = gnomevfs.unescape_string(selection.data, '').strip()
+			file_path = urllib.unquote(selection.data).strip()
 			if not file_path.startswith('file:'):
 				return
-			file_info = gnomevfs.get_file_info(
-				file_path, gnomevfs.FILE_INFO_GET_MIME_TYPE|
-				gnomevfs.FILE_INFO_FORCE_SLOW_MIME_TYPE|
-				gnomevfs.FILE_INFO_FOLLOW_LINKS|gnomevfs.FILE_INFO_DEFAULT
-				)
-			if file_info.mime_type == 'application/x-desktop':
-				handle = gnomevfs.open(file_path)
-				data = handle.read(file_info.size)
-				open('/tmp/alacarte-dnd.desktop', 'w').write(data)
+			myfile = gio.File(uri=file_path)
+			file_info = myfile.query_info(gio.FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE)
+			content_type = file_info.get_content_type()
+			if content_type == 'application/x-desktop':
+				input_stream = myfile.read()
+				open('/tmp/alacarte-dnd.desktop', 'w').write(input_stream.read())
 				parser = util.DesktopParser('/tmp/alacarte-dnd.desktop')
 				self.editor.createItem(parent, parser.get('Icon'), parser.get('Name', self.editor.locale), parser.get('Comment', self.editor.locale), parser.get('Exec'), parser.get('Terminal'), before, after)
-			elif file_info.mime_type in ('application/x-shellscript', 'application/x-executable'):
+			elif content_type in ('application/x-shellscript', 'application/x-executable'):
 				self.editor.createItem(parent, None, os.path.split(file_path)[1].strip(), None, file_path.replace('file://', '').strip(), False, before, after)
 		self.drag_data = None
 
@@ -600,7 +596,7 @@ class MainWindow:
 		self.editor.redo()
 
 	def on_help_button_clicked(self, *args):
-		gnome.help_display_desktop(self.gnome_program, 'user-guide', 'user-guide.xml', 'menu-editor')
+		gtk.show_uri(gtk.gdk.screen_get_default(), "ghelp:user-guide#menu-editor", gtk.get_current_event_time())
 
 	def on_revert_button_clicked(self, button):
 		dialog = self.tree.get_widget('revertdialog')
